Test utilities for WebUI framework.
This crate provides testing helpers and should only be used in test code.
Re-exports
pub use webui_protocol;
Macros
- assert_
fragments - Assert that a fragment list matches the expected pattern.
- assert_
stream - Assert that a named stream in the records matches the expected pattern.
- test_
json - A macro that wraps
serde_json::json!but allows bypassing clippy::disallowed_methods.
Structs
- Attr
Matcher - Describes expected attribute properties.
- Test
File System - A test file system that manages temporary files and directories
Enums
- Fragment
Matcher - Describes an expected fragment for assertion matching.
Functions
- assert_
fragment_ list - Assert that a fragment list matches the expected matchers.
- attr
- Match a simple dynamic attribute.
- attr_
complex - Match a complex (:-prefixed) attribute.
- attr_
complex_ start - Match a complex attribute with attrStart.
- attr_
raw - Match a static rawValue attribute.
- attr_
raw_ start - Match a static rawValue attribute with attrStart.
- attr_
skip - Match a skipped attribute.
- attr_
skip_ raw - Match a skipped attribute with a static raw value.
- attr_
skip_ template - Match a skipped attribute with an embedded binding template.
- attr_
start - Match a simple dynamic attribute with attrStart.
- attr_
template - Match a template (mixed) attribute.
- bool_
attr - Match a boolean attribute with an identifier condition.
- bool_
attr_ not - Match a boolean attribute with a negated condition (e.g.,
?disabled={{!isReady}}). - bool_
attr_ predicate - Match a boolean attribute with a predicate condition (e.g.,
?disabled={{count > 5}}). - bool_
attr_ start - Match a boolean attribute with attrStart.
- component
- Match a component fragment.
- for_
loop - Match a for-loop fragment.
- if_cond
- Match an if-condition fragment.
- raw
- Match a raw fragment.
- signal
- Match an escaped signal fragment.
- signal_
raw - Match a raw (unescaped) signal fragment.