pub fn assert_fragment_list(
fragments: &[WebUIFragment],
matchers: &[FragmentMatcher],
)Expand description
Assert that a fragment list matches the expected matchers.
pub fn assert_fragment_list(
fragments: &[WebUIFragment],
matchers: &[FragmentMatcher],
)Assert that a fragment list matches the expected matchers.