pub fn attr_skip_raw(name: &str, value: &str) -> FragmentMatcherExpand description
Match a skipped attribute with a static raw value.
pub fn attr_skip_raw(name: &str, value: &str) -> FragmentMatcherMatch a skipped attribute with a static raw value.