pub fn attr_skip_template(name: &str, template: &str) -> FragmentMatcherExpand description
Match a skipped attribute with an embedded binding template.
pub fn attr_skip_template(name: &str, template: &str) -> FragmentMatcherMatch a skipped attribute with an embedded binding template.