macro_rules! assert_stream {
($records:expr, $stream_id:expr, [ $($matcher:expr),* $(,)? ]) => { ... };
}Expand description
Assert that a named stream in the records matches the expected pattern.
macro_rules! assert_stream {
($records:expr, $stream_id:expr, [ $($matcher:expr),* $(,)? ]) => { ... };
}Assert that a named stream in the records matches the expected pattern.