macro_rules! test_json {
($($json:tt)+) => { ... };
}Expand description
A macro that wraps serde_json::json! but allows bypassing clippy::disallowed_methods.
This macro should only be used in test code.
macro_rules! test_json {
($($json:tt)+) => { ... };
}A macro that wraps serde_json::json! but allows bypassing clippy::disallowed_methods.
This macro should only be used in test code.