AttrMatcher

Struct AttrMatcher 

pub struct AttrMatcher {
    pub name: String,
    pub value: Option<String>,
    pub template: Option<String>,
    pub complex: bool,
    pub attr_start: bool,
    pub attr_skip: bool,
    pub raw_value: bool,
    pub bool_signal: Option<String>,
    pub bool_predicate: Option<(String, i32, String)>,
    pub bool_not: Option<String>,
}
Describes expected attribute properties.

Fields

name: Stringvalue: Option<String>template: Option<String>complex: boolattr_start: boolattr_skip: boolraw_value: boolbool_signal: Option<String>bool_predicate: Option<(String, i32, String)>

Match a boolean attribute with a predicate condition (left, op, right).

bool_not: Option<String>

Match a boolean attribute with a negation condition (inner identifier).