Crate webui_test_utils

Crate webui_test_utils 

Test utilities for WebUI framework.

This crate provides testing helpers and should only be used in test code.

Re-exports

pub use webui_protocol;

Macros

assert_fragments
Assert that a fragment list matches the expected pattern.
assert_stream
Assert that a named stream in the records matches the expected pattern.
test_json
A macro that wraps serde_json::json! but allows bypassing clippy::disallowed_methods.

Structs

AttrMatcher
Describes expected attribute properties.
TestFileSystem
A test file system that manages temporary files and directories

Enums

FragmentMatcher
Describes an expected fragment for assertion matching.

Functions

assert_fragment_list
Assert that a fragment list matches the expected matchers.
attr
Match a simple dynamic attribute.
attr_complex
Match a complex (:-prefixed) attribute.
attr_complex_start
Match a complex attribute with attrStart.
attr_raw
Match a static rawValue attribute.
attr_raw_start
Match a static rawValue attribute with attrStart.
attr_skip
Match a skipped attribute.
attr_start
Match a simple dynamic attribute with attrStart.
attr_template
Match a template (mixed) attribute.
bool_attr
Match a boolean attribute with an identifier condition.
bool_attr_not
Match a boolean attribute with a negated condition (e.g., ?disabled={{!isReady}}).
bool_attr_predicate
Match a boolean attribute with a predicate condition (e.g., ?disabled={{count > 5}}).
bool_attr_start
Match a boolean attribute with attrStart.
component
Match a component fragment.
for_loop
Match a for-loop fragment.
if_cond
Match an if-condition fragment.
raw
Match a raw fragment.
signal
Match an escaped signal fragment.
signal_raw
Match a raw (unescaped) signal fragment.